@@ -18,7 +18,7 @@ sys.path.insert(0, os.path.abspath('../'))
 # -- Project information -----------------------------------------------------
 
 project = 'openautomatumdronedata'
-copyright = '2021, Peter Zechel'
+copyright = '2022, Automatum Data'
 author = 'Peter Zechel'
 
 # The full version, including alpha/beta/rc tags
@@ -55,7 +55,7 @@ source_suffix = {
 # The theme to use for HTML and HTML Help pages.  See the documentation for
 # a list of builtin themes.
 #
-html_theme = 'classic'
+html_theme = 'renku'
 
 # Add any paths that contain custom static files (such as style sheets) here,
 # relative to this directory. They are copied after the builtin static files,
